@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Canonical
+ * Copyright (C) 2011-2020 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -390,6 +390,7 @@ static int file_get_uint64(const char *const file, uint64_t *val)
 {
 	FILE *fp;
 
+	*val = 0;
 	if ((fp = fopen(file, "r")) == NULL)
 		return -1;
 
@@ -1764,6 +1765,7 @@ static char *power_get_rapl_domain_names(void)
 		char *tmp;
 		size_t new_len;
 
+		new_name[0] = '\0';
 		(void)snprintf(new_name, sizeof(new_name), "%s%s",
 				len == 0 ? "" : ", ", rapl->domain_name);
 		new_len = strlen(new_name);
@@ -2574,6 +2576,8 @@ static int monitor(const int sock)
 		free(stats);
 		return -1;
 	}
+	s2 = s1;
+
 	if (opts & OPTS_CSTATES)
 		cpu_states_update();
 	if (opts & OPTS_GPU)
